@@ -1,4 +1,4 @@
-#' @importFrom stats na.omit rnorm median
+#' @importFrom stats na.omit median
 #' @importFrom utils setTxtProgressBar txtProgressBar head capture.output
 #' @importFrom methods is
 #' @importFrom magrittr %>%
@@ -6,4 +6,4 @@
 NULL
 
 #' @importFrom utils globalVariables
-utils::globalVariables(c('.', 'long', 'lat', 'region', 'patches', 'p'))
+utils::globalVariables(c('.', 'long', 'lat', 'region', 'patches', 'p', 'focal', 'neighbor', 'values'))
